pub enum TryRecvError {
Empty,
Closed,
}Expand description
Error returned by the try_recv function on Receiver.
Variants
Empty
The send half of the channel has not yet sent a value.
Closed
The send half of the channel was dropped without sending a value.