OwnedRwLockMappedWriteGuard

Struct OwnedRwLockMappedWriteGuard 

pub struct OwnedRwLockMappedWriteGuard<T, U = T>
where T: ?Sized, U: ?Sized,
{ /* private fields */ }
Owned RAII structure used to release the exclusive write access of a lock when dropped.

This structure is created by mapping an OwnedRwLockWriteGuard. It is a separate type from OwnedRwLockWriteGuard to disallow downgrading a mapped guard, since doing so can cause undefined behavior.

Implementations

Source

impl<T, U> OwnedRwLockMappedWriteGuard<T, U>
where T: ?Sized, U: ?Sized,

pub fn map<F, V>( this: OwnedRwLockMappedWriteGuard<T, U>, f: F, ) -> OwnedRwLockMappedWriteGuard<T, V>
where F: FnOnce(&mut U) -> &mut V, V: ?Sized,

Makes a new OwnedRwLockMappedWriteGuard for a component of the locked data.

This operation cannot fail as the OwnedRwLockMappedWriteGuard passed in already locked the data.

This is an associated function that needs to be used as OwnedRwLockWriteGuard::map(..). A method would interfere with methods of the same name on the contents of the locked data.

Examples
use std::sync::Arc;
use tokio::sync::{RwLock, OwnedRwLockWriteGuard};

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
struct Foo(u32);

let lock = Arc::new(RwLock::new(Foo(1)));

{
    let lock = Arc::clone(&lock);
    let mut mapped = OwnedRwLockWriteGuard::map(lock.write_owned().await, |f| &mut f.0);
    *mapped = 2;
}

assert_eq!(Foo(2), *lock.read().await);
pub fn try_map<F, V>( this: OwnedRwLockMappedWriteGuard<T, U>, f: F, ) -> Result<OwnedRwLockMappedWriteGuard<T, V>, OwnedRwLockMappedWriteGuard<T, U>>
where F: FnOnce(&mut U) -> Option<&mut V>, V: ?Sized,

Attempts to make a new OwnedRwLockMappedWriteGuard for a component of the locked data. The original guard is returned if the closure returns None.

This operation cannot fail as the OwnedRwLockMappedWriteGuard passed in already locked the data.

This is an associated function that needs to be used as OwnedRwLockMappedWriteGuard::try_map(...). A method would interfere with methods of the same name on the contents of the locked data.

Examples
use std::sync::Arc;
use tokio::sync::{RwLock, OwnedRwLockWriteGuard};

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
struct Foo(u32);

let lock = Arc::new(RwLock::new(Foo(1)));

{
    let guard = Arc::clone(&lock).write_owned().await;
    let mut guard = OwnedRwLockWriteGuard::try_map(guard, |f| Some(&mut f.0)).expect("should not fail");
    *guard = 2;
}

assert_eq!(Foo(2), *lock.read().await);
pub fn rwlock(this: &OwnedRwLockMappedWriteGuard<T, U>) -> &Arc<RwLock<T>>

Returns a reference to the original Arc<RwLock>.

Examples
use std::sync::Arc;
use tokio::sync::{
    RwLock,
    OwnedRwLockWriteGuard,
    OwnedRwLockMappedWriteGuard,
};

let lock = Arc::new(RwLock::new(1));

let guard = lock.clone().write_owned().await;
let guard = OwnedRwLockWriteGuard::map(guard, |x| x);
assert!(Arc::ptr_eq(&lock, OwnedRwLockMappedWriteGuard::rwlock(&guard)));