Struct ruva::tokio::sync::TryLockError
source · pub struct TryLockError(/* private fields */);Expand description
Error returned from the Mutex::try_lock, RwLock::try_read and
RwLock::try_write functions.
Mutex::try_lock operation will only fail if the mutex is already locked.
RwLock::try_read operation will only fail if the lock is currently held
by an exclusive writer.
RwLock::try_write operation will only fail if the lock is currently held
by any reader or by an exclusive writer.